@@ -5,7 +5,7 @@ To turn on verbose logging
 import logging
 logging.getLogger('calcbench.api_client').setLevel(logging.INFO)
 """
-__version__ = "3.0.12"
+__version__ = "3.1.1"
 from .api_client import (
     CompanyIdentifierScheme,
     as_reported_raw,
@@ -17,11 +17,6 @@ from .api_client import (
     enable_backoff,
     face_statement,
     html_diff,
-    mapped_raw,
-    normalized_data,
-    normalized_dataframe,
-    normalized_raw,
-    point_in_time,
     press_release_raw,
     raw_data,
     raw_data_raw,
@@ -29,11 +24,18 @@ from .api_client import (
     raw_xbrl_raw,
     set_credentials,
     set_proxies,
-    standardized_data,
     tag_contents,
 )
-from .disclosures import document_contents, document_search
+from .disclosures import document_search
 from .companies import tickers, companies, companies_raw
 from .listener import handle_filings
 from .filing import filings, Filing
 from .metrics import available_metrics, available_metrics_dataframe
+from .standardized_numeric import (
+    mapped_raw,
+    normalized_data,
+    normalized_dataframe,
+    normalized_raw,
+    point_in_time,
+    standardized_data,
+)
\ No newline at end of file
